Module alt

Module alt 

This module provides an Altitude type, crate::lat! macro, and a Coordinate3d structure which is a lat/long Coordinate with an altitude.

Structs

Altitude
An altitude, in meters, above or below sea level.
Coordinate3d
A three dimensional geographic coordinate expressed as a (latitude, longitude, altitude) triple.