Altitude

Struct Altitude 

pub struct Altitude(/* private fields */);
An altitude, in meters, above or below sea level.

Implementations

Source

impl Altitude

pub fn sea_level() -> Self

Construct a new altitude value for sea level, i.e. 0 m.

pub fn centimeters(value: f64) -> Self

Construct an altitude in centimeters.

pub fn meters(value: f64) -> Self

Construct an altitude in meters.

pub fn kilometers(value: f64) -> Self

Construct an altitude in kilometers.

pub fn value(&self) -> f64