Coordinate3d

Struct Coordinate3d 

pub struct Coordinate3d { /* private fields */ }
A three dimensional geographic coordinate expressed as a (latitude, longitude, altitude) triple.

Examples

use lat_long::{Altitude, Angle, Coordinate3d, Latitude, Longitude};

let lat = Latitude::try_from(47.6204).unwrap();
let lon = Longitude::try_from(-122.3491).unwrap();
let height = Altitude::meters(226.0);
let top_of_seattle_space_needle = Coordinate3d::new_from(lat, lon, height);

println!("{top_of_seattle_space_needle}");   // decimal degrees
println!("{top_of_seattle_space_needle:#}"); // degrees–minutes–seconds

Implementations

Source

impl Coordinate3d

pub const fn new(point: Coordinate, altitude: Altitude) -> Self

Construct a new 3d coordinate from a 2d point and an altitude.

pub const fn new_from( lat: Latitude, long: Longitude, altitude: Altitude, ) -> Self

Construct a new 3d coordinate from a 2d point, expressed as latitude and longitude values, and an altitude.

pub const fn with_point(self, point: Coordinate) -> Self

Return a new Coordinate3d with the point component replaced.

pub const fn with_new_point(self, lat: Latitude, long: Longitude) -> Self

Return a new Coordinate3d with the point component replaced by a new 2d coordinate.

pub const fn with_altitude(self, altitude: Altitude) -> Self

Return a new Coordinate3d with the altitude component replaced.

pub const fn point(&self) -> Coordinate

Returns the 2d coordinate component of this 3d coordinate.

pub const fn altitude(&self) -> Altitude

Returns the altitude component of this 3d coordinate.

pub fn is_on_equator(&self) -> bool

Returns true if this coordinate lies on the equator.

pub fn is_northern(&self) -> bool

Returns true if this coordinate is in the northern hemisphere.

pub fn is_southern(&self) -> bool

Returns true if this coordinate is in the southern hemisphere.

pub fn is_on_international_reference_meridian(&self) -> bool

Returns true if this coordinate lies on the international reference meridian.

pub fn is_western(&self) -> bool

Returns true if this coordinate is in the western hemisphere.

pub fn is_eastern(&self) -> bool

Returns true if this coordinate is in the eastern hemisphere.

pub fn is_at_sea_level(&self) -> bool

Returns true if this coordinate lies on the equator.