Module coord

Module coord 

This module provides the Coordinate type, crate::coord! macro, and associated constants.

A geographic coordinate system (GCS) is a spherical or geodetic coordinate system for measuring and communicating positions directly on Earth as latitude and longitude. It is the simplest, oldest, and most widely used type of the various spatial reference systems that are in use, and forms the basis for most others. Although latitude and longitude form a coordinate tuple like a Cartesian coordinate system, geographic coordinate systems are not Cartesian because the measurements are angles and are not on a planar surface.

Structs

Coordinate
A geographic coordinate expressed as a (latitude, longitude) pair.

Constants

GEO_URL_SCHEME
The URI scheme used by Coordinate::to_url_string to format a geo: URI.