This module provides an Elevation type, crate::elv! macro, and a CoordinateWithElevation
structure which is a lat/long Coordinate with an associated elevation.
The elevation of a geographic location is its height above or below a fixed reference point, most commonly a reference geoid, a mathematical model of the Earth’s sea level as an equipotential gravitational surface (see Geodetic datum  Vertical datum).
The reference point for the type Elevation is not defined, therefore any absolute value must
be calculated by conversion from convention in reference to some datum.
Structs
- Coordinate
With Elevation - A three dimensional geographic coordinate expressed as a (latitude, longitude, elevation) triple.
- Elevation
- An elevation, in meters, above or below an undefined reference level.