CoordinateWithElevation

Struct CoordinateWithElevation 

pub struct CoordinateWithElevation { /* private fields */ }
A three dimensional geographic coordinate expressed as a (latitude, longitude, elevation) triple.

Examples

use lat_long::{Elevation, Angle, CoordinateWithElevation, Latitude, Longitude};

let lat = Latitude::try_from(47.6204).unwrap();
let lon = Longitude::try_from(-122.3491).unwrap();
let height = Elevation::meters(226.0);
let top_of_seattle_space_needle = CoordinateWithElevation::new_from(lat, lon, height);

println!("{top_of_seattle_space_needle}");   // decimal degrees
println!("{top_of_seattle_space_needle:#}"); // degrees–minutes–seconds

Implementations

Source

impl CoordinateWithElevation

pub const fn new(point: Coordinate, elevation: Elevation) -> Self

Construct a new 3d coordinate from a 2d point and an elevation.

pub const fn new_from( lat: Latitude, long: Longitude, elevation: Elevation, ) -> Self

Construct a new 3d coordinate from a 2d point, expressed as latitude and longitude values, and an elevation.

pub const fn with_point(self, point: Coordinate) -> Self

Return a new 3d coordinate with the point component replaced.

pub const fn with_new_point(self, lat: Latitude, long: Longitude) -> Self

Return a new 3d coordinate with the point component replaced by a new 2d coordinate.

pub const fn with_elevation(self, elevation: Elevation) -> Self

Return a new CoordinateWithElevation with the elevation component replaced.

pub const fn point(&self) -> Coordinate

Returns the 2d coordinate component of this 3d coordinate.

pub const fn elevation(&self) -> Elevation

Returns the elevation component of this 3d coordinate.

pub fn is_on_equator(&self) -> bool

Returns true if this coordinate lies on the equator.

pub fn is_northern(&self) -> bool

Returns true if this coordinate is in the northern hemisphere.

pub fn is_southern(&self) -> bool

Returns true if this coordinate is in the southern hemisphere.

pub fn is_on_international_reference_meridian(&self) -> bool

Returns true if this coordinate lies on the international reference meridian.

pub fn is_western(&self) -> bool

Returns true if this coordinate is in the western hemisphere.

pub fn is_eastern(&self) -> bool

Returns true if this coordinate is in the eastern hemisphere.

pub fn is_zero_elevation(&self) -> bool

Returns true if this coordinate lies on the equator.