Elevation

Struct Elevation 

pub struct Elevation(/* private fields */);
An elevation, in meters, above or below an undefined reference level.

Implementations

Source

impl Elevation

pub fn zero() -> Self

Zero is ambiguous as an elevation, since it could represent either sea level, or the ground level at the location of interest, or a Geodetic vertical datum.

pub fn centimeters(value: f64) -> Self

Construct an elevation in centimeters.

pub fn meters(value: f64) -> Self

Construct an elevation in meters.

pub fn kilometers(value: f64) -> Self

Construct an elevation in kilometers.

pub fn value(&self) -> f64

Returns the elevation value in meters as an f64.

pub fn is_zero(&self) -> bool

Returns true if this elevation is exactly zero.