pub struct Elevation(/* private fields */);Expand description
An elevation, in meters, above or below an undefined reference level.
Implementations
Sourceimpl Elevation
impl Elevation
Sourcepub fn zero() -> Self
pub fn zero() -> Self
Zero is ambiguous as an elevation, since it could represent either sea level, or the ground level at the location of interest, or a Geodetic vertical datum.
Sourcepub fn centimeters(value: f64) -> Self
pub fn centimeters(value: f64) -> Self
Construct an elevation in centimeters.
Sourcepub fn kilometers(value: f64) -> Self
pub fn kilometers(value: f64) -> Self
Construct an elevation in kilometers.