FormatOptions

Struct FormatOptions 

pub struct FormatOptions { /* private fields */ }
The default format is FormatKind::Decimal (plain decimal degrees). When you use the alternate flag ({:#}) the default DMS variant is used.

Implementations

Source

impl FormatOptions

pub const fn decimal() -> Self

Return a FormatOptions for decimal degrees with the default precision.

pub const fn dms() -> Self

Return a FormatOptions for degrees, minutes, seconds with the default precision.

pub const fn dms_signed() -> Self

Return a FormatOptions for signed degrees, minutes, seconds with the default precision.

pub const fn dms_labeled() -> Self

Return a FormatOptions for labeled degrees, minutes, seconds with the default precision.

pub const fn dms_bare() -> Self

Return a FormatOptions for bare degrees, minutes, seconds with the default precision.

pub const fn with_precision(self, precision: usize) -> Self

pub const fn with_default_precision(self) -> Self

pub const fn with_labels(self, labels: (char, char)) -> Self

pub const fn with_latitude_labels(self) -> Self

pub const fn with_longitude_labels(self) -> Self

pub const fn kind(&self) -> FormatKind

pub const fn is_decimal(&self) -> bool

pub const fn is_dms(&self) -> bool

pub const fn is_dms_signed(&self) -> bool

pub const fn is_dms_labeled(&self) -> bool

pub const fn is_dms_bare(&self) -> bool

pub const fn precision(&self) -> Option<usize>

pub const fn labels(&self) -> Option<(char, char)>

pub fn positive_label(&self) -> Option<char>

pub fn negative_label(&self) -> Option<char>