pub struct Longitude(/* private fields */);Expand description
A geographic longitude value, constrained to −180 ≤ degrees ≤ 180.
Positive values are east of the international reference meridian; negative values are west.
Examples
use lat_long::{Angle, Longitude};
let lon = Longitude::new(-73, 56, 0.0).unwrap();
assert!(lon.is_western());Implementations
Sourceimpl Longitude
impl Longitude
Sourcepub fn is_on_international_reference_meridian(&self) -> bool
pub fn is_on_international_reference_meridian(&self) -> bool
Returns true if this longitude is exactly on the IERS International Reference Meridian (IRM), or 0°.
Sourcepub fn is_western(&self) -> bool
pub fn is_western(&self) -> bool
Returns true if this longitude is in the western hemisphere (< 0°).
Sourcepub fn is_eastern(&self) -> bool
pub fn is_eastern(&self) -> bool
Returns true if this longitude is in the eastern hemisphere (> 0°).